import os
import sys

from ._version import VERSION
from .ply_class import Ply
from .laminate_class import Laminate
from .load_class import Load
from .strength_class import Strength

__version__ = VERSION